==> escudo-0.4.tbz2: escudo-0.4/components/menuAutoComplete.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */

Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");

function MenuAutoComplete() {
  //we need to retrieve the top most window, to obtain the root object for escudo
  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                     .getService(Components.interfaces["nsIWindowMediator"]);
  this.root = wm.getMostRecentWindow("Escudo:Window").top;
}

MenuAutoComplete.prototype = {
  classDescription: "Escudo menu auto complete",
  classID:          Components.ID("{0e7bff90-0d6c-11de-8c30-0800200cda66}"),
  contractID:       "@mozilla.org/autocomplete/search;1?name=menu-autocomplete",
  QueryInterface:   XPCOMUtils.generateQI([Components.interfaces.nsIAutoCompleteSearch]),

  startSearch: function(searchString, searchParam, previousResult, listener) {
    var menu = this.root.Escudo.Accounts.getAccountsMatchingPattern(searchString);
    var result = {
      results: null,
      defaultIndex: 0,
      errorDescription: null,
      matchCount: 0,
      searchResult: Components.interfaces.nsIAutoCompleteResult.RESULT_SUCCESS,
      searchString: searchString,
      getCommentAt: function(index){ },
      getStyleAt: function(index) {
        var val = this.results[index];
        if (val == "Comptes" || val == "Tags" || val == "Beneficiaires") {
          return "menu-container";
        } else {
          return "menu-leaf";
        }
      },
      getImageAt: function(index){},
      getValueAt: function(index){return this.results[index]},
      removeValueAt: function(rowIndex, removeFromDb) {}
    }

    /**/
    menu.splice(0, 0, "Comptes")
    menu.push("Tags");
    menu.push("Beneficiaires");

    result.results = menu;
    result.matchCount = menu.length;
    listener.onSearchResult(this, result);
  },

  stopSearch: function() {}
};

var components = [MenuAutoComplete];

function NSGetModule(compMgr, fileSpec) {
  return XPCOMUtils.generateModule(components);
}

==> escudo-0.4.1.tbz2: escudo-0.4.1/components/menuAutoComplete.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */

Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");

function MenuAutoComplete() {
  //we need to retrieve the top most window, to obtain the root object for escudo
  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                     .getService(Components.interfaces["nsIWindowMediator"]);
  this.root = wm.getMostRecentWindow("Escudo:Window").top;
}

MenuAutoComplete.prototype = {
  classDescription: "Escudo menu auto complete",
  classID:          Components.ID("{0e7bff90-0d6c-11de-8c30-0800200cda66}"),
  contractID:       "@mozilla.org/autocomplete/search;1?name=menu-autocomplete",
  QueryInterface:   XPCOMUtils.generateQI([Components.interfaces.nsIAutoCompleteSearch]),

  startSearch: function(searchString, searchParam, previousResult, listener) {
    var accounts = this.root.Escudo.Accounts.getAccountsMatchingPattern(searchString);
    var payees = this.root.Escudo.Payees.getPayeesMatchingPattern(searchString);

    var result = {
      rootLevel: null,
      results: null,
      defaultIndex: 0,
      errorDescription: null,
      matchCount: 0,
      searchResult: Components.interfaces.nsIAutoCompleteResult.RESULT_SUCCESS,
      searchString: searchString,
      getCommentAt: function(index){ },
      getStyleAt: function(index) {
        var val = this.results[index];
        if (this.rootLevel.indexOf(val) != -1) {
          return "menu-container";
        } else {
          return "menu-leaf";
        }
      },
      getImageAt: function(index){},
      getValueAt: function(index){return this.results[index]},
      removeValueAt: function(rowIndex, removeFromDb) {}
    }

    result.rootLevel = [this.root.EscudoLib.$STR("menu_keyIndicator"),
                        this.root.EscudoLib.$STR("menu_payees")];
    
    var menu = [];
    if (accounts.length > 0) {
      menu.push(this.root.EscudoLib.$STR("menu_keyIndicator"));
      menu = menu.concat(accounts);
    }
    
    if (payees.length > 0) {
      menu.push(this.root.EscudoLib.$STR("menu_payees"));
      menu = menu.concat(payees);
    }
    
    result.results = menu;
    result.matchCount = menu.length;
    listener.onSearchResult(this, result);
  },

  stopSearch: function() {}
};

var components = [MenuAutoComplete];

function NSGetModule(compMgr, fileSpec) {
  return XPCOMUtils.generateModule(components);
}
